import { GoogleResponseStatus } from "./google";
import { Coordinate } from "./objects";
export declare type TravelMode = "driving" | "walking" | "bicycling" | "transit";
export declare type TransitMode = "bus" | "subway" | "train" | "tram" | "rail";
export declare type DirectionsResponseStatus = "NOT_FOUND" | "MAX_WAYPOINTS_EXCEEDED" | "MAX_ROUTE_LENGTH_EXCEEDED" | "OVER_DAILY_LIMIT" | GoogleResponseStatus;
export interface DirectionsResponse {
    status: DirectionsResponseStatus;
    error_message?: object;
    geocoded_waypoints?: GeocodedWaypoint[];
    routes?: Route[];
    available_travel_modes?: (TransitMode | TravelMode)[];
    fare?: Fare;
}
export interface GeocodedWaypoint {
    geocoder_status?: string;
    place_id?: string;
    types?: string[];
}
export interface RouteComponents {
    start_location?: Coordinate;
    end_location?: Coordinate;
    start_address?: string;
    end_address?: string;
    duration?: ValueAndText;
}
export interface Route extends RouteComponents {
    summary?: string;
    legs?: RouteLeg[];
    warnings?: any[];
    copyrights?: string;
    overview_polyline?: Polyline;
    waypoint_order?: number[];
}
export interface RouteLeg extends RouteComponents {
    steps?: RouteStep[];
    distance?: ValueAndText;
    duration?: ValueAndText;
    duration_in_traffic?: ValueAndText;
    arrival_time?: Time;
    departure_time?: Time;
}
export interface ValueAndText {
    value: number;
    text: string;
}
export interface Fare extends ValueAndText {
    currency: string;
}
export interface Time {
    value: Date;
    text: string;
    time_zome: string;
}
export interface RouteStep extends BasicStep {
    steps?: BasicStep[];
}
export interface BasicStep extends RouteComponents {
    travel_mode?: TravelMode | TransitMode;
    polyline?: Polyline;
    distance?: ValueAndText;
    html_instructions?: string;
    transit_details?: TransitDetail;
}
export interface TransitDetail {
    arrival_stop?: TransitLocation;
    departure_stop?: TransitLocation;
    arrival_time: Time;
    departure_time: Time;
    headway?: number;
    num_strops?: number;
    trip_short_name?: string;
    line?: TransitLine;
}
export interface TransitLocation {
    name?: string;
    location?: Coordinate;
}
export interface TransitLine {
    name?: string;
    short_name?: string;
    color?: string;
    agencies?: TransitAgency[];
    url?: string;
    icon?: string;
    text_color?: string;
    vehicle?: TransitVehicle;
}
export declare type VehicleType = "RAIL" | "METRO_RAIL" | "SUBWAY" | "TRAM" | "MONORAIL" | "HEAVYRAIL" | "COMMUTER_TRAIN" | "HIGH_SPEED_TRAIN" | "LONG_DISTANCE_TRAIN" | "BUS" | "INTERCITY_BUS" | "TROLLEYBUS" | "SHARE_TAXI" | "FERRY" | "CABLE_CAR" | "GONDOLA_LIFT" | "FUNICULAR" | "OTHER";
export interface TransitVehicle {
    name?: string;
    icon?: string;
    type?: VehicleType;
    local_icon?: string;
}
export interface TransitAgency {
    name?: string;
    phone?: string;
    url?: string;
}
export interface Polyline {
    points: string;
}
