import { DirectionsResponse } from "./googledirections";
export interface BasicUser {
    uId: string;
    firstName: string;
    lastName: string;
    email: string;
    phoneNumber?: string;
}
export interface User extends BasicUser {
}
export interface Booking {
    bookingId: string;
    cost: number;
    referenceId: string;
}
export interface BookingEntry {
    bookingId: string;
    tripId: string;
    destinationId: string;
    points: number;
}
export interface TripLeg {
    tripId: string;
    destinationId: string;
    beginDate: string;
    endDate: string;
}
export interface Hotel {
    hotelId: string;
    name: string;
    destinationId: string;
    description: string;
    title: string;
    rooms?: Room[];
}
export interface Room {
    roomId: string;
    beds: number;
    description: string;
    title: string;
}
export interface RoomBooking extends Room, Booking {
    hotelId: string;
}
export interface Destination {
    destinationId: string;
    name: string;
    state: string;
    region: string;
    country: string;
    hotels?: Hotel[];
}
export interface Venue {
    venueId: string;
    destinationId: string;
    name: string;
    website: string;
    phone: string;
    email: string;
    events?: Event[];
}
export interface Event {
    eventId: string;
    activityId: string;
    startTime: string;
    endTime: number;
}
export interface EventBooking extends Event, Booking {
    eventId: string;
}
export interface Color {
    red: number;
    blue: number;
    green: number;
}
export interface Coordinate {
    lat: number;
    lng: number;
}
export declare function isCoordinate(args: any): args is Coordinate;
export interface TripGenerationInputs {
    numberOfPeople?: number;
    budget?: number;
    startDate: number;
    endDate: number;
    startLocation: Coordinate;
    endLocation: Coordinate;
    tripName: string;
}
export interface Trip {
    tripId: string;
    tripName: string;
    trip: Activity[];
    directions?: DirectionsResponse[];
}
export interface Activity {
    name: string;
    price?: number;
    location: string;
    generalLocation: string;
    description?: string;
    time: number;
    duration: number;
    people?: string;
    rating?: number;
    types: string[];
    place_id: string;
}
export declare type PlaceType = QueryPlaceType | AdditionalResultPlaceType;
export declare type QueryPlaceType = 'accounting' | 'airport' | 'atm' | 'bank' | 'bar' | 'beauty_salon' | 'bicycle_store' | 'book_store' | 'bus_station' | 'car_dealer' | 'car_rental' | 'car_repair' | 'car_wash' | 'casino' | 'cemetery' | 'church' | 'clothing_store' | 'convenience_store' | 'courthouse' | 'dentist' | 'department_store' | 'doctor' | 'drugstore' | 'electrician' | 'electronics_store' | 'embassy' | 'fire_station' | 'florist' | 'funeral_home' | 'furniture_store' | 'gas_station' | 'gym' | 'hair_care' | 'hardware_store' | 'hindu_temple' | 'home_goods_store' | 'hospital' | 'insurance_agency' | 'jewelry_store' | 'laundry' | 'lawyer' | 'light_rail_station' | 'liquor_store' | 'local_government_office' | 'locksmith' | 'meal_delivery' | 'mosque' | 'movie_rental' | 'moving_company' | 'painter' | 'parking' | 'pet_store' | 'pharmacy' | 'physiotherapist' | 'plumber' | 'police' | 'post_office' | 'primary_school' | 'real_estate_agency' | 'lodging' | 'roofing_contractor' | 'rv_park' | 'school' | 'secondary_school' | 'shoe_store' | 'shopping_mall' | 'stadium' | 'storage' | 'store' | 'subway_station' | 'supermarket' | 'synagogue' | 'taxi_stand' | 'train_station' | 'transit_station' | 'travel_agency' | 'university' | 'veterinary_care' | PlacesToGo;
export declare type PlacesToGo = 'restaurant' | 'bakery' | 'cafe' | 'meal_takeaway' | NonFoodPlacesToGo;
export declare const FOOD_PLACES_TO_GO: PlaceType[];
export declare type NonFoodPlacesToGo = 'amusement_park' | 'aquarium' | 'art_gallery' | 'movie_theater' | 'museum' | 'park' | 'tourist_attraction' | 'zoo' | 'spa' | 'library' | 'night_club' | 'campground' | 'bowling_alley' | 'city_hall';
export declare type AdditionalResultPlaceType = 'administrative_area_level_1' | 'administrative_area_level_2' | 'administrative_area_level_3' | 'administrative_area_level_4' | 'administrative_area_level_5' | 'archipelago' | 'colloquial_area' | 'continent' | 'country' | 'establishment' | 'finance' | 'floor' | 'food' | 'general_contractor' | 'geocode' | 'health' | 'intersection' | 'landmark' | 'locality' | 'natural_feature' | 'neighborhood' | 'place_of_worship' | 'plus_code' | 'point_of_interest' | 'political' | 'post_box' | 'postal_code' | 'postal_code_prefix' | 'postal_code_suffix' | 'postal_town' | 'premise' | 'room' | 'route' | 'street_address' | 'street_number' | 'sublocality' | 'sublocality_level_1' | 'sublocality_level_2' | 'sublocality_level_3' | 'sublocality_level_4' | 'sublocality_level_5' | 'subpremise' | 'town_square';
