import { postContent } from "./networking";
import { Trip, TripGenerationInputs } from "./objects";

let base_backend_url = "http://localhost:4000"

/** Sets the base url for Travelogue's backend, used for all subsequent requests 
 * @param url The base url
*/
export const setBaseBackendUrl = (url: string) => {
    if (url == null || url === "") {
        throw new Error(`Backend url cannot be set to null/empty string`);
    }
    if (url.charAt(url.length - 1) === "/") {
        url = url.slice(0, url.length - 1);
    }
    base_backend_url = url;
}

const generateUrl = (endpoint: string) => `${base_backend_url}/${endpoint}`;

/** Generate a new trip based on the input parameters 
 * @param input The trip generation inputs to be used
 * @param errorMessage An optional error message in the case that the response fails
*/
export const generateNewTrip = (input: TripGenerationInputs, errorMessage?: string) => {
    const body = JSON.stringify(input);
    const url = generateUrl("trip/new");
    return postContent<Trip>({ url, errorMessage, body });
}
