import { Coordinate } from "./objects";

/** Returns a boolean describing whether a coordinate point is valid, ensuring lat and lng are non-null */
export const coordinatesAreValid = (point: Coordinate) => {
    return point != null && point.lat != null && point.lng != null;
}

/** Finds the distance beween two coordinates in metres */
export const distanceBetweenTwoCoordinates = (point1: Coordinate, point2: Coordinate) => {  // generally used geo measurement function
    const R = 6378.137; // Radius of earth in KM
    const rads = Math.PI / 180;
    const dLat = (point2.lat - point1.lat) * rads * 0.5;
    const dLon = (point2.lng - point1.lng) * rads * 0.5;
    const dLatSin = Math.sin(dLat);
    const dLonSin = Math.sin(dLon);
    const a = dLatSin * dLatSin +
        Math.cos(point1.lat * rads) * Math.cos(point2.lat * rads) * dLonSin * dLonSin;
    const c = 2 * Math.atan2(Math.sqrt(a), Math.sqrt(1 - a));
    const d = R * c;
    return d * 1000; // meters
}

/** Gets the midpoint between two coordinates, by averaging them  */
export const getMidpointBetweenTwoCoordinates = (point1: Coordinate, point2: Coordinate): Coordinate => {  // generally used geo measurement function
    return {
        lat: (point1.lat + point2.lat) * 0.5,
        lng: (point1.lng + point2.lng) * 0.5
    }
}
